@@ -62,6 +62,7 @@ import com.sencha.gxt.data.shared.loader.LoadResultListStoreBinding;
 import com.sencha.gxt.data.shared.loader.PagingLoadResult;
 import com.sencha.gxt.data.shared.loader.PagingLoader;
 import com.sencha.gxt.widget.core.client.ContentPanel;
+import com.sencha.gxt.widget.core.client.container.MarginData;
 import com.sencha.gxt.widget.core.client.container.VerticalLayoutContainer;
 import com.sencha.gxt.widget.core.client.container.VerticalLayoutContainer.VerticalLayoutData;
 import com.sencha.gxt.widget.core.client.event.HeaderContextMenuEvent;
@@ -137,10 +138,16 @@ public class TabularDataXGridPanel extends ContentPanel {
 		super();
 		this.tdSessionId = tdSessionId;
 		this.eventBus = eventBus;
+		setBodyBorder(false);
+		setBorders(false);
+		setHeaderVisible(false);
+		forceLayoutOnResize=true;
+		setResize(true);
 		bindEventBus();
 		container = new VerticalLayoutContainer();
-
-		setWidget(container);
+		container.setBorders(false);
+		add(container,new MarginData(0));
+		//setWidget(container);
 	}
 
 	/**
@@ -743,7 +750,8 @@ public class TabularDataXGridPanel extends ContentPanel {
 			grid.setLoadMask(true);
 			grid.setLoader(loader);
 			grid.setView(liveGridView);
-
+			grid.setBorders(false);
+			
 			// TODO disabled editing rows
 			/*
 			 * editing = new GridInlineEditing<DataRow>(grid);
@@ -769,14 +777,14 @@ public class TabularDataXGridPanel extends ContentPanel {
 
 			//
 			container.add(grid, new VerticalLayoutData(1, 1, new Margins(0)));
-
+			
 			toolBar = new ToolBar();
 			toolBar.add(new LiveToolItem(grid));
 			toolBar.addStyleName(ThemeStyles.getStyle().borderTop());
 			toolBar.getElement().getStyle().setProperty("borderBottom", "none");
 
 			container.add(toolBar,
-					new VerticalLayoutData(1, 25, new Margins(0)));
+					new VerticalLayoutData(1, 24, new Margins(0)));
 
 			container.forceLayout();
 
@@ -929,22 +937,46 @@ public class TabularDataXGridPanel extends ContentPanel {
 	 *            index of column in ColumnModel
 	 * @return id of column and equals to column name on service
 	 */
-	public String getColumnId(int i) {
+	public String getColumnName(int i) {
 		Log.debug("Retrive Column Id of column:" + i);
-		String columnId = null;
+		String columnName = null;
 		if (grid != null) {
 			ColumnModel<DataRow> columnModel = grid.getColumnModel();
 			List<ColumnConfig<DataRow, ?>> columns = columnModel.getColumns();
 
 			DataRowColumnConfig<?> dc = (DataRowColumnConfig<?>) columns.get(i);
 
-			columnId = dc.getDefinition().getId();
-			Log.debug("Column - Definition: Id: " + columnId);
+			columnName = dc.getDefinition().getId();
+			Log.debug("Column - Definition: Id: " + columnName);
 
 		}
-		return columnId;
+		return columnName;
 	}
 
+	
+	/**
+	 * 
+	 * @param i
+	 *            index of column in ColumnModel
+	 * @return id of column and equals to column name on service
+	 */
+	public String getColumnLocalId(int i) {
+		Log.debug("Retrive Column Local Id of column:" + i);
+		String columnLocalId = null;
+		if (grid != null) {
+			ColumnModel<DataRow> columnModel = grid.getColumnModel();
+			List<ColumnConfig<DataRow, ?>> columns = columnModel.getColumns();
+
+			DataRowColumnConfig<?> dc = (DataRowColumnConfig<?>) columns.get(i);
+
+			columnLocalId = dc.getDefinition().getColumnLocalId();
+			Log.debug("Column - Definition: Column Local Id: " + columnLocalId);
+
+		}
+		return columnLocalId;
+	}
+	
+	
 	/**
 	 * 
 	 * @param rows
